Backend.AI Manager with API Gateway
===================================

Package Structure
-----------------

* ``ai.backend``

  * ``manager``: Abstraction of agents and computation kernels

  * ``gateway``: User and Admin API (REST/GraphQL) gateway based on aiohttp

Installation
------------

Please visit `the installation guides <https://github.com/lablup/backend.ai/wiki>`_.
